<template>
    <div class="profile">
        <div class="lds-dual-ring" v-if="isLoading"></div>
        <div v-else>
            <div class="profile__header">
                <span>Профиль участника</span>
                <span @click="$modal.hideAll();"><i class="fa fa-times" aria-hidden="true"></i></span>
            </div>
            <div class="profile__body">
                <img :src="profile.photo_200" />
                <span class="profile__username">
                    {{ profile.username }}&nbsp;
                    <i 
                        class="fa fa-external-link" 
                        aria-hidden="true" 
                        title="Страница ВКонтакте"
                        @click="openVK()"
                        v-if="profile.vk_id != null && !profile.privacy_hide"
                    ></i>
                </span>
                <div class="profile__stats">
                    <div class="stats__item">
                        <span>Ставок в Jackpot</span>
                        <span v-if="!profile.privacy_hide">{{ parseFloat(profile.jackpot_bets).toFixed(2) }} Р</span>
                        <span v-else>Скрыто</span>
                    </div>
                    <div class="stats__item">
                        <span>Выиграно в Jackpot</span>
                        <span v-if="!profile.privacy_hide">{{ parseFloat(profile.jackpot_win).toFixed(2) }} Р</span>
                        <span v-else>Скрыто</span>
                    </div>
                </div>

                </div>
            </div>
        </div>
    </div>
</template>

<script>
export default {
    props: ['id'],
    data() {
        return {
            isLoading: true,
            btnLoading: false,
            amount: null,
            profile: {}
        }
    },
    mounted() {
        this.init(this.id)
    },
    methods: {
        init(id) {
            this.$root.axios.post('/profile', {
                id
            })
            .then(response => {
                const {data} = response
                this.isLoading = false
                this.profile = data
            })
            .catch(error => {
                this.$modal.hideAll()
            })
        },
        send() {
            this.btnLoading = true
            this.$root.axios.post('/profile/send', {
                user_id: this.profile.id,
                amount: this.amount
            })
            .then(response => {
                const {data} = response
                this.btnLoading = false;

                if(data.error) {
                    return notify({
                        theme: 'red',
                        text: data.message
                    })
                }

                notify({
                    theme: 'green',
                    text: 'Перевод выполнен'
                })

                this.$root.user.balance = data.balance
                this.amount = ''
            })
        },
        openVK() {
            window.open(`https://vk.com/id${this.profile.vk_id}`)
        }
    }
}
</script>

<style scoped>
.profile {
    display: flex;
    background: #fff;
    flex-direction: column;
}

.profile__header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 20px;
    font-weight: 400;
    min-height: 40px;
}

.profile__body {
    position: relative;
    flex: 1 1 auto;
    padding: 1.5rem;
    background: #f8fafc;
    justify-content: center;
    display: flex;
    flex-direction: column;
    align-items: center;
}

.profile__username {
    font-size: 18px;
    margin-top: 14px
}

.profile__group {
    margin-top: 20px;
    display: flex
}

.profile__stats {
    display: flex
}

.stats__item {
    margin: 5px;
    text-align: center;
    padding: 10px;
    border-radius: 6px;
}

.stats__item > span {
    display: flex;
    flex-direction: column;
    margin-top: 10px;
}

.stats__item > span:nth-child(2) {
    color: #2c80ff
}

input {
    padding: 10px;
    max-width: 80%;
}

button {
    background: #3164b0;
    color: #fff;
    border: none;
    padding: 12px;
    min-width: 20%;
}

button:not(disabled) {
    cursor: pointer;
}

button:disabled {
    opacity: .4;
    cursor: not-allowed
}

img {
    width: 56px;
    height: 56px;
    border-radius: 3px
}

.fa-times {
    color: #c3bdde;
    cursor: pointer;
    font-size: 24px;
}

.fa-external-link {
    cursor: pointer
}

.lds-dual-ring {
    display: flex;
    margin: auto;
    width: 80px;
    height: 80px;
}
.lds-dual-ring:after {
    content: " ";
    display: block;
    width: 40px;
    height: 40px;
    margin: auto;
    border-radius: 50%;
    border: 2px solid #e6e4f1;
    border-top-color: rgb(230, 228, 241);
    border-right-color: rgb(230, 228, 241);
    border-bottom-color: rgb(230, 228, 241);
    border-left-color: rgb(230, 228, 241);
    border-color: #e6e4f1 transparent #e6e4f1 transparent;
    animation: lds-dual-ring-data-v-314fa2e8 1.2s linear infinite;
}
@keyframes lds-dual-ring {
    0% {
        transform: rotate(0deg);
    }
    100% {
        transform: rotate(360deg);
    }
}
</style>